import {View} from "@tarojs/components";
import {getCurrentInstance} from "@tarojs/runtime";
import {ManageApi} from "@/api/manage";
import React, {FC, useCallback, useEffect, useState} from "react";
import Taro from "@tarojs/taro";
import VideoCover from "@/components/videoCover/videoCover";
import Empty from "@/components/empty/empty";

interface AddProps {
  cur_id: number,
  name: string,
  index: number
}

const AddCur = () => {
  const {id} = getCurrentInstance()?.router?.params as { id: string }
  const [data, setData] = useState<Curriculum[]>([])
  const [page] = useState(1)


  const getData = useCallback(async () => {
    try {
      const res = await ManageApi.optionalCur(Number(id), page, 10)
      if (res.length) {
        setData(res)
      }
    } catch (e) {

    }
  }, [page])

  useEffect(() => {
    getData()
  }, [])

  const Add: FC<AddProps> = ({cur_id, name, index}) => {
    function addCur() {
      Taro.showModal({
        title: "请选择" + name + '课程类型',
        cancelText: '选修',
        confirmText: '必修',
        async success({confirm}) {
          try {
            const is_required = confirm ? 1 : 0
            Taro.showLoading()
            await ManageApi.addCur({course_id: [cur_id], dep_id: [Number(id)], is_required})
            const oldData: Curriculum[] = JSON.parse(JSON.stringify(data))
            oldData.splice(index, 1)
            setData(oldData)
            Taro.showToast({title: "添加成功"})
          } catch (e) {
          }
          Taro.hideLoading()
        }
      })
    }

    return (
      <View className='text-center mt-1' onClick={addCur}>添加课程</View>
    )
  }

  return (
    <>
      {
        data.length ?
          <View className='bg-white mt-2 py-2 flex flex-wrap'>
            {data?.map((d, index) => (
              <VideoCover
                key={d.id}
                thumb={d.thumb}
                title={<Add cur_id={d.id} name={d.title} index={index}/>}
                id={d.id}
                depId={Number(id)}
                content={d.title}
              />
            ))}
          </View>
          : <Empty name='无更多课程'/>
      }
    </>
  )
}

export default AddCur
